##  Required Attributes
For your initial application portfolio assessment, you need the following attributes for business capabilities:
  * Name
  * Description
  * Related parent and child business capabilities
